import esbuild from "esbuild";
import process from "process";
import builtins from 'builtin-modules'
import child_process from 'child_process'
import fs from 'fs'

const prod = (process.argv[2] === 'production');

let runScriptPlugin = {
	name: 'run-script',
	setup(build) {
		build.onEnd(result => {
			if (result.errors.length > 0) {
				return
			}
			const scriptName = 'sync-plugin.sh'
			if (!fs.existsSync(scriptName)) {
				return
			}
			console.log(`run ${scriptName}`);
			child_process.execSync(`bash ${scriptName}`, (err, stdout, stderr) => {
				if (err) {
					console.error(`run ${scriptName} error:`, err, stdout, stderr)
				}
			})
		})
	},
}

esbuild.build({
	banner: {
		js: `/* THIS IS A GENERATED/BUNDLED FILE BY ESBUILD */`,
	},
	entryPoints: ['main.ts'],
	bundle: true,
	external: [
		'obsidian',
		'electron',
		'@codemirror/autocomplete',
		'@codemirror/closebrackets',
		'@codemirror/collab',
		'@codemirror/commands',
		'@codemirror/comment',
		'@codemirror/fold',
		'@codemirror/gutter',
		'@codemirror/highlight',
		'@codemirror/history',
		'@codemirror/language',
		'@codemirror/lint',
		'@codemirror/matchbrackets',
		'@codemirror/panel',
		'@codemirror/rangeset',
		'@codemirror/rectangular-selection',
		'@codemirror/search',
		'@codemirror/state',
		'@codemirror/stream-parser',
		'@codemirror/text',
		'@codemirror/tooltip',
		'@codemirror/view',
		...builtins],
	format: 'cjs',
	watch: !prod,
	target: 'es2016',
	logLevel: "info",
	sourcemap: prod ? false : 'inline',
	treeShaking: true,
	outfile: 'main.js',
	plugins: [runScriptPlugin],
}).catch(() => process.exit(1));
